pub struct DesktopAppHandle { /* private fields */ }Expand description
A handle which represents a desktop application.
Implementations
Sourceimpl DesktopAppHandle
impl DesktopAppHandle
Sourcepub fn name_locale(&self) -> String
pub fn name_locale(&self) -> String
Returns the localized name of the application.
Sourcepub fn generic_name(&self) -> Option<String>
pub fn generic_name(&self) -> Option<String>
Returns the generic name of the application.
For example: Web browser.
Sourcepub fn generic_name_locale(&self) -> Option<String>
pub fn generic_name_locale(&self) -> Option<String>
Returns the localized generic name of the application.
Sourcepub fn icon(&self) -> Option<String>
pub fn icon(&self) -> Option<String>
Returns the icon of the application.
It’s either the name of the icon or the absolute path.
Sourcepub fn icon_locale(&self) -> Option<String>
pub fn icon_locale(&self) -> Option<String>
Returns the localized icon of the application.
Sourcepub fn keywords_locale(&self) -> Vec<String>
pub fn keywords_locale(&self) -> Vec<String>
Returns a list of localized keywords describing the application.
Sourcepub fn exec(&self) -> Option<String>
pub fn exec(&self) -> Option<String>
Returns the string containing the program to execute, possibly with arguments.
Sourcepub fn actions(&self) -> Vec<ActionHandle>
pub fn actions(&self) -> Vec<ActionHandle>
Returns a list of application actions. Can be empty.