pub struct ApplicationService {
pub on_apps_refreshed: Event<()>,
/* private fields */
}Expand description
A service to access desktop applications.
Fields
on_apps_refreshed: Event<()>Emitted when the list of installed applications changed.
This can occur, for example, when an application is installed or removed from the system.
Implementations
Sourceimpl ApplicationService
impl ApplicationService
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new instance.
It loads all application entries from XDG_DATA_DIRS and gets the system locale.
Sourcepub fn watch(&self) -> Result<()>
pub fn watch(&self) -> Result<()>
Starts watching for changes in application entries. Re-initializes apps if a change occurs.
Errors
Error::NotifyError
Sourcepub fn apps(&self) -> Vec<DesktopAppHandle>
pub fn apps(&self) -> Vec<DesktopAppHandle>
Returns a list of applications.
Sourcepub fn app_by_id(&self, app_id: &str) -> Option<DesktopAppHandle>
pub fn app_by_id(&self, app_id: &str) -> Option<DesktopAppHandle>
Returns an application by its ID, or None if it is not found.
Sourcepub fn search_by_name(&self, query: &str) -> Vec<DesktopAppHandle>
pub fn search_by_name(&self, query: &str) -> Vec<DesktopAppHandle>
Fuzzily search through the application entries by provided application name.